# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__title__ = "RFD CLI"
__author__ = "Dave Gallant"
__license__ = "Apache 2.0"
__copyright__ = "(c) 2018 Dave Gallant"

API_BASE_URL = "https://forums.redflagdeals.com"
